=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2010-03-31 05:53:34 +0000
+++ drizzled/sql_yacc.yy	2010-03-31 19:14:14 +0000
@@ -4765,7 +4765,7 @@
              }
              else
              {
-               if (prepare_new_schema_table(session, lex, "SCHEMA_NAMES"))
+               if (prepare_new_schema_table(session, lex, "SHOW_SCHEMAS"))
                  DRIZZLE_YYABORT;
              }
 

=== modified file 'plugin/schema_dictionary/dictionary.cc'
--- plugin/schema_dictionary/dictionary.cc	2010-03-10 18:22:56 +0000
+++ plugin/schema_dictionary/dictionary.cc	2010-03-31 19:14:14 +0000
@@ -67,6 +67,8 @@
   context.add(table_constraints);
   context.add(table_status);
   context.add(tables);
+
+  context.add(new ShowSchemas());
   
   return 0;
 }

=== modified file 'plugin/schema_dictionary/dictionary.h'
--- plugin/schema_dictionary/dictionary.h	2010-03-05 22:56:46 +0000
+++ plugin/schema_dictionary/dictionary.h	2010-03-31 19:14:14 +0000
@@ -41,6 +41,7 @@
 #include "plugin/schema_dictionary/show_columns.h"
 #include "plugin/schema_dictionary/show_indexes.h"
 // Show tables needs to be first.
+#include "plugin/schema_dictionary/show_schemas.h"
 #include "plugin/schema_dictionary/show_tables.h"
 #include "plugin/schema_dictionary/show_table_status.h"
 #include "plugin/schema_dictionary/show_temporary_tables.h"

=== modified file 'plugin/schema_dictionary/plugin.ini'
--- plugin/schema_dictionary/plugin.ini	2010-03-23 03:07:21 +0000
+++ plugin/schema_dictionary/plugin.ini	2010-03-31 19:14:14 +0000
@@ -11,6 +11,7 @@
   schemas.cc
   show_columns.cc
   show_indexes.cc
+  show_schemas.cc
   show_table_status.cc
   show_tables.cc
   show_temporary_tables.cc
@@ -25,6 +26,7 @@
   schemas.h
   show_columns.h
   show_indexes.h
+  show_schemas.h
   show_table_status.h
   show_tables.h
   show_temporary_tables.h

=== added file 'plugin/schema_dictionary/show_schemas.cc'
--- plugin/schema_dictionary/show_schemas.cc	1970-01-01 00:00:00 +0000
+++ plugin/schema_dictionary/show_schemas.cc	2010-03-31 19:14:14 +0000
@@ -0,0 +1,104 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+#include "plugin/schema_dictionary/dictionary.h"
+
+using namespace std;
+using namespace drizzled;
+
+ShowSchemas::ShowSchemas() :
+  plugin::TableFunction("DATA_DICTIONARY", "SHOW_SCHEMAS")
+{
+  add_field("SCHEMA_NAME");
+}
+
+ShowSchemas::Generator::Generator(Field **arg) :
+  plugin::TableFunction::Generator(arg),
+  is_schema_primed(false)
+{
+}
+
+/**
+  @note return true if a match occurs.
+*/
+bool ShowSchemas::Generator::checkSchema()
+{
+  if (isWild((*schema_iterator).getSchemaName()))
+    return true;
+
+  return false;
+}
+
+bool ShowSchemas::Generator::nextSchemaCore()
+{
+  if (is_schema_primed)
+  {
+    schema_iterator++;
+  }
+  else
+  {
+    Session *session= current_session;
+    plugin::StorageEngine::getSchemaIdentifiers(*session, schema_names);
+    schema_names.sort();
+    schema_iterator= schema_names.begin();
+    is_schema_primed= true;
+  }
+
+  if (schema_iterator == schema_names.end())
+    return false;
+
+  if (checkSchema())
+      return false;
+
+  return true;
+}
+  
+bool ShowSchemas::Generator::nextSchema()
+{
+  while (not nextSchemaCore())
+  {
+    if (schema_iterator == schema_names.end())
+      return false;
+  }
+
+  return true;
+}
+
+
+bool ShowSchemas::Generator::populate()
+{
+  if (nextSchema())
+  {
+    fill();
+    return true;
+  }
+
+  return false;
+}
+
+/**
+  A lack of a parsed schema file means we are using defaults.
+*/
+void ShowSchemas::Generator::fill()
+{
+  /* Schema */
+  push((*schema_iterator).getSchemaName());
+}

=== added file 'plugin/schema_dictionary/show_schemas.h'
--- plugin/schema_dictionary/show_schemas.h	1970-01-01 00:00:00 +0000
+++ plugin/schema_dictionary/show_schemas.h	2010-03-31 19:14:14 +0000
@@ -0,0 +1,63 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef PLUGIN_SCHEMA_DICTIONARY_SHOW_SCHEMAS_H
+#define PLUGIN_SCHEMA_DICTIONARY_SHOW_SCHEMAS_H
+
+class ShowSchemas : public drizzled::plugin::TableFunction
+{
+public:
+
+  ShowSchemas();
+
+  ShowSchemas(const char *schema_arg, const char *table_arg) :
+    drizzled::plugin::TableFunction(schema_arg, table_arg)
+  { }
+
+  class Generator : public drizzled::plugin::TableFunction::Generator 
+  {
+    drizzled::SchemaIdentifierList schema_names;
+    drizzled::SchemaIdentifierList::const_iterator schema_iterator;
+
+    bool is_schema_primed;
+
+    virtual void fill();
+    virtual bool checkSchema();
+
+  public:
+    Generator(drizzled::Field **arg);
+
+    bool populate();
+    bool nextSchemaCore();
+    bool nextSchema();
+    bool isSchemaPrimed()
+    {
+      return is_schema_primed;
+    }
+  };
+
+  Generator *generator(drizzled::Field **arg)
+  {
+    return new Generator(arg);
+  }
+};
+
+
+#endif /* PLUGIN_SCHEMA_DICTIONARY_SHOW_SCHEMAS_H */

=== modified file 'plugin/schema_dictionary/tests/r/data_dictionary.result'
--- plugin/schema_dictionary/tests/r/data_dictionary.result	2010-03-20 20:33:18 +0000
+++ plugin/schema_dictionary/tests/r/data_dictionary.result	2010-03-31 19:14:14 +0000
@@ -464,6 +464,7 @@
 #
 #
 #
+#
 SELECT count(*) FROM REFERENTIAL_CONSTRAINTS;
 count(*)
 #

=== modified file 'tests/r/1st.result'
--- tests/r/1st.result	2010-02-24 20:14:09 +0000
+++ tests/r/1st.result	2010-03-31 19:14:14 +0000
@@ -1,7 +1,7 @@
 show databases;
 Database
-data_dictionary
-information_schema
+DATA_DICTIONARY
+INFORMATION_SCHEMA
 mysql
 test
 select concat("Starting in ", database());

=== modified file 'tests/r/data_dictionary_like_info.result'
--- tests/r/data_dictionary_like_info.result	2010-03-26 23:47:08 +0000
+++ tests/r/data_dictionary_like_info.result	2010-03-31 19:14:14 +0000
@@ -10,8 +10,8 @@
 test
 show databases;
 Database
-data_dictionary
-information_schema
+DATA_DICTIONARY
+INFORMATION_SCHEMA
 mysql
 test
 create database mysqltest;
@@ -191,7 +191,7 @@
  or DATA_TYPE = 'varchar')
 group by DATA_TYPE order by DATA_TYPE, num;
 DATA_TYPE	group_concat(table_schema, '.', table_name)	num
-VARCHAR	DATA_DICTIONARY.CHARACTER_SETS,DATA_DICTIONARY.CHARACTER_SETS,DATA_DICTIONARY.CHARACTER_SETS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.GLOBAL_STATEMENTS,DATA_DICTIONARY.GLOBAL_STATEMENTS,DATA_DICTIONARY.GLOBAL_STATUS,DATA_DICTIONARY.GLOBAL_STATUS,DATA_DICTIONARY.GLOBAL_VARIABLES,DATA_DICTIONARY.GLOBAL_VARIABLES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEX_PART	143
+VARCHAR	DATA_DICTIONARY.CHARACTER_SETS,DATA_DICTIONARY.CHARACTER_SETS,DATA_DICTIONARY.CHARACTER_SETS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLLATIONS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.COLUMNS,DATA_DICTIONARY.GLOBAL_STATEMENTS,DATA_DICTIONARY.GLOBAL_STATEMENTS,DATA_DICTIONARY.GLOBAL_STATUS,DATA_DICTIONARY.GLOBAL_STATUS,DATA_DICTIONARY.GLOBAL_VARIABLES,DATA_DICTIONARY.GLOBAL_VARIABLES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEXES,DATA_DICTIONARY.INDEX_PART	144
 Warnings:
 Warning	1260	1 line(s) were cut by GROUP_CONCAT()
 create table t1(f1 char(1) not null, f2 char(9) not null);

=== modified file 'tests/r/drop.result'
--- tests/r/drop.result	2010-03-26 20:07:44 +0000
+++ tests/r/drop.result	2010-03-31 19:14:14 +0000
@@ -46,8 +46,8 @@
 create database mysqltest;
 show databases;
 Database
-data_dictionary
-information_schema
+DATA_DICTIONARY
+INFORMATION_SCHEMA
 mysql
 mysqltest
 test
@@ -58,8 +58,8 @@
 drop database mysqltest;
 show databases;
 Database
-data_dictionary
-information_schema
+DATA_DICTIONARY
+INFORMATION_SCHEMA
 mysql
 test
 drop database mysqltest;

=== modified file 'tests/r/information_schema.result'
Binary files tests/r/information_schema.result and tests/r/information_schema.result differ
=== modified file 'tests/r/schema.result'
--- tests/r/schema.result	2010-02-25 04:05:56 +0000
+++ tests/r/schema.result	2010-03-31 19:14:14 +0000
@@ -5,9 +5,9 @@
 foo	CREATE DATABASE `foo` COLLATE = utf8_general_ci
 show schemas;
 Database
-data_dictionary
+DATA_DICTIONARY
 foo
-information_schema
+INFORMATION_SCHEMA
 mysql
 test
 drop schema foo;

=== modified file 'tests/r/show_check.result'
--- tests/r/show_check.result	2010-03-23 04:40:43 +0000
+++ tests/r/show_check.result	2010-03-31 19:14:14 +0000
@@ -78,15 +78,15 @@
 Session	Schema	Name	Type	Engine	Version	Rows	Avg_row_length	Table_size	Auto_increment
 show databases;
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
-def	data_dictionary	schema_names	SCHEMA_NAMES	SCHEMA_NAME	Database	8	256	18	N	1	0	45
+def	data_dictionary	show_schemas	SHOW_SCHEMAS	SCHEMA_NAME	Database	8	256	18	N	1	0	45
 Database
-data_dictionary
-information_schema
+DATA_DICTIONARY
+INFORMATION_SCHEMA
 mysql
 test
 show databases like "test%";
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
-def	data_dictionary	schema_names	SCHEMA_NAMES	SCHEMA_NAME	Database (test%)	8	256	4	N	1	0	45
+def	data_dictionary	show_schemas	SHOW_SCHEMAS	SCHEMA_NAME	Database (test%)	8	256	4	N	1	0	45
 Database (test%)
 test
 create table t1 (f1 int not null, f2 int not null, f3 int not null, f4 int not null, primary key(f1,f2,f3,f4));

